@@ -1345,28 +1345,35 @@ def launch_main_window(uid, title, url, width, height, resizable, full_screen, m
         browser_subprocess_path_venv = os.path.abspath("./venv/lib/python" + python_version + "/site-packages/cefpython3/subprocess")
         exist_venv = os.path.exists(framework_dir_path_venv)
 
-        # APP 生产编译模式下，Contents/Resources下的路径
-        framework_dir_path_app = os.path.abspath("./lib/python" + python_version + "/cefpython3/Chromium Embedded Framework.framework")
-        browser_subprocess_path_app = os.path.abspath("./lib/python" + python_version + "/cefpython3/subprocess")
-        exist_app = os.path.exists(framework_dir_path_app)
+        # py2app 生产编译模式下，Contents/Resources下的路径
+        framework_dir_path_py2app = os.path.abspath("./lib/python" + python_version + "/cefpython3/Chromium Embedded Framework.framework")
+        browser_subprocess_path_py2app = os.path.abspath("./lib/python" + python_version + "/cefpython3/subprocess")
+        exist_py2app = os.path.exists(framework_dir_path_py2app)
 
         # py2app 本地编译打包 -A 参数控制的alias模式下，应使用系统环境路径
         framework_dir_path_system = os.path.abspath(sys.base_prefix + "/lib/python" + python_version + "/site-packages/cefpython3/Chromium Embedded Framework.framework")
         browser_subprocess_path_system = os.path.abspath(sys.base_prefix + "/lib/python" + python_version + "/site-packages/cefpython3/subprocess")
         exist_system = os.path.exists(framework_dir_path_system)
 
-        if exist_app:
-            framework_dir_path = framework_dir_path_app
-            browser_subprocess_path = browser_subprocess_path_app
+        framework_dir_path_pyinstaller = os.path.abspath(sys.base_prefix + "/Chromium Embedded Framework.framework")
+        browser_subprocess_path_pyinstaller = os.path.abspath(sys.base_prefix + "/subprocess")
+        exist_pyinstaller = os.path.exists(framework_dir_path_pyinstaller)
+
+        if exist_py2app:
+            framework_dir_path = framework_dir_path_py2app
+            browser_subprocess_path = browser_subprocess_path_py2app
         elif exist_system:
             framework_dir_path = framework_dir_path_system
             browser_subprocess_path = browser_subprocess_path_system
+        elif exist_pyinstaller:
+            framework_dir_path = framework_dir_path_pyinstaller
+            browser_subprocess_path = browser_subprocess_path_pyinstaller
         else:
             framework_dir_path = framework_dir_path_venv
             browser_subprocess_path = browser_subprocess_path_venv
 
-        print("framework_dir_path : ", framework_dir_path)
-        print("browser_subprocess_path : ", browser_subprocess_path)
+        print("[ CEF LOG ] framework_dir_path : ", framework_dir_path)
+        print("[ CEF LOG ] browser_subprocess_path : ", browser_subprocess_path)
 
         settings["framework_dir_path"] = framework_dir_path
         settings["browser_subprocess_path"] = browser_subprocess_path
